import random
import socket


def getPort(minPort, maxPort):
    ports = list(range(minPort, maxPort))
    random.shuffle(ports)
    for port in ports:
        try:
            sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
            sock.bind(('', port))
            sock.close()
            return port
        except socket.error:
            pass
    raise RuntimeError('could not bind to a port')



# -*- coding: utf-8 -*-

from distutils.core import setup

setup(name='porty',
      packages=['porty'],
      version='0.0.1',
      description='Get a free port from a specified range',
      author='André Gaul',
      author_email='andre@gaul.io',
      url='https://github.com/andrenarchy/porty',
      scripts=['scripts/porty'],
      classifiers=[
          'Intended Audience :: System Administrators',
          'Topic :: System :: Systems Administration',
          'Topic :: System :: Networking'
          ]
      )
